@@ -54,11 +54,18 @@ public:
      */
     KCompressionDevice(const QString &fileName, CompressionType type);
 
+    /**
+     * Constructs a KCompressionDevice for a given @p fileName.
+     * @param fileName the name of the file to filter.
+     * @since 5.85
+     */
+    explicit KCompressionDevice(const QString &fileName);
+
     /**
      * Destructs the KCompressionDevice.
      * Calls close() if the filter device is still open.
      */
-    virtual ~KCompressionDevice();
+    ~KCompressionDevice() override;
 
     /**
      * The compression actually used by this device.
@@ -106,6 +113,13 @@ public:
      */
     static KFilterBase *filterForCompressionType(CompressionType type);
 
+    /**
+     * Returns the compression type for the given MIME type, if possible. Otherwise returns None.
+     * This handles simple cases like application/gzip, but also application/x-compressed-tar, and inheritance.
+     * @since 5.85
+     */
+    static CompressionType compressionTypeForMimeType(const QString &mimetype);
+
     /**
      * Returns the error code from the last failing operation.
      * This is especially useful after calling close(), which unfortunately returns void
